*********************
WeatherAlerts
*********************


**WeatherAlerts a python package that pulls in the National Weather Service (NWS) Common Alerting Protocol (CAP) Emergency / Severe Weather Alerts feed, parses it and provides interaction with currently active alerts.**



Documentation Contents
-----------------------

.. toctree::
   :maxdepth: 2

   about
   nwsdata
   use
   webservice
   module
   changelog

* :ref:`genindex`
* :ref:`search`


This module is maintained by Zeb Palmer, a Linux Systems Engineer and Professional Photographer who writes a bit of python at work and play. See my other work at `Zeb Palmer <http://www.zebpalmer.com>`_








